# bioIB
bioIB package for scRNA-seq analysis

This repository provides the code for bioIB, described in our article - 
"bioIB: Identifying informative metagenes in single-cell RNA-seq with the Information Bottleneck algorithm"

![image](https://github.com/SimaDubnov/bioIB/assets/76960862/daf3b06c-263f-4792-9de2-3d72832b6c50)

bioIB is a novel method for scRNA-seq analysis, based on the Information Bottleneck algorithm. 
Given the cellular labels representing the signal of interest, such as cell type, bioIB generates probabilistic gene clusters, or metagenes, that capture the major biological processes differentially activated between the defined cellular populations.

# This repository

This repository contains:

1. The bioIB package code.
2. Jupyter notebook tutorial exemplifying the use of the bioIB package functions.
